@@ -209,6 +209,8 @@ class AnalysisSTEAM:
                 self.step_setup_folder(step, verbose=verbose)
             elif step.type == 'AddAuxiliaryFile':
                 self.add_auxiliary_file(step, verbose=verbose)
+            elif step.type == 'CopyFile':
+                self.copy_file_to_target(step, verbose=verbose)
             else:
                 raise Exception('Unknown type of analysis step: {}'.format(step.type))
 
@@ -524,6 +526,21 @@ class AnalysisSTEAM:
                 if 'PSPICE' in step.software:
                     self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
 
+    def copy_file_to_target(self, step, verbose: bool = False):
+        """
+            Copy one file from a location to another (the destination folder can be different from the analysis output folder)
+        """
+        # Unpack
+        full_path_file_to_copy = Path(step.full_path_file_to_copy).resolve()
+        full_path_file_target  = Path(step.full_path_file_target).resolve()
+
+        # Make sure the target folder exists
+        make_folder_if_not_existing(os.path.dirname(full_path_file_target), verbose=verbose)
+
+        # Copy file
+        shutil.copyfile(full_path_file_to_copy, full_path_file_target)
+        if verbose: print(f'File {full_path_file_to_copy} was copied to {full_path_file_target}.')
+
     def setup_sim_FiQuS(self, simulation_name, simulation_type, sim_number):
         """
         Set up a FiQuS simulation by copying the last file generated by BuilderModel to the output folder and to the
