@@ -11,7 +11,6 @@ class BuilderFiQuS:
     def __init__(self,
                  input_model_data: dM.DataModelMagnet = None,
                  input_roxie_data: dR.RoxieData = None,
-                 local_model_path: str = None,
                  flag_build: bool = True,
                  flag_plot_all: bool = False,
                  verbose: bool = True):
@@ -22,7 +21,6 @@ class BuilderFiQuS:
         # Unpack arguments
         self.verbose: bool = verbose
         self.flag_plot_all: bool = flag_plot_all
-        self.local_folder: str = local_model_path
         self.model_data: dM.DataModelMagnet = input_model_data
         self.roxie_data: dR.RoxieData = input_roxie_data
 
@@ -36,8 +34,8 @@ class BuilderFiQuS:
         self.data_FiQuS.run = self.model_data.Options_FiQuS.run
 
         if self.data_FiQuS.magnet.type == 'multipole':
-            self.data_FiQuS_geo = dF.FiQuSGeometry()
-            self.data_FiQuS_set = dF.FiQuSSettings()
+            self.data_FiQuS_geo = dF.MultipoleGeometry()
+            self.data_FiQuS_set = dF.MultipoleSettings()
             if flag_build:
                 self.buildDataMultipole()
 
@@ -56,13 +54,12 @@ class BuilderFiQuS:
         # windings
         for key, value in self.model_data.Options_FiQuS.cct.geometry.windings.dict().items():       # for keys that are present in the FiQUS Options model data (but not all keys in data FiQuS)
             self.data_FiQuS.magnet.geometry.windings.__setattr__(key, value)
-        self.data_FiQuS.magnet.geometry.windings.n_turnss = self.model_data.CoilWindings.CCT_straight.winding_numberTurnsFormers # additional, picked form other places in model data
+        self.data_FiQuS.magnet.geometry.windings.n_turnss = self.model_data.CoilWindings.CCT_straight.winding_numberTurnsFormers  # additional, picked form other places in model data
 
         self.data_FiQuS.magnet.postproc.windings_wwns = self.model_data.CoilWindings.CCT_straight.winding_numRowStrands
         self.data_FiQuS.magnet.postproc.windings_whns = self.model_data.CoilWindings.CCT_straight.winding_numColumnStrands
         self.data_FiQuS.magnet.postproc.winding_order = self.model_data.CoilWindings.CCT_straight.winding_order
 
-
         # fqpls
         self.data_FiQuS.magnet.geometry.fqpls = self.model_data.Options_FiQuS.cct.geometry.fqpls
 
@@ -95,7 +92,7 @@ class BuilderFiQuS:
         self.data_FiQuS_set.Model_Data_GS.general_parameters.I_ref = \
             [self.model_data.Options_LEDET.field_map_files.Iref] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
         for cond in self.model_data.Conductors:
-            self.data_FiQuS_set.Model_Data_GS.conductors[cond.name] = dF.ConductorFiQuS(cable={'type': cond.cable.type})
+            self.data_FiQuS_set.Model_Data_GS.conductors[cond.name] = dF.MultipoleConductor(cable={'type': cond.cable.type})
             conductor = self.data_FiQuS_set.Model_Data_GS.conductors[cond.name]
             conductor.cable.bare_cable_width = cond.cable.bare_cable_width
             conductor.cable.bare_cable_height_mean = cond.cable.bare_cable_height_mean
@@ -109,5 +106,7 @@ class BuilderFiQuS:
         self.data_FiQuS.magnet.solve.I_initial = \
             [self.model_data.Power_Supply.I_initial] * len(self.data_FiQuS_geo.Roxie_Data.coil.coils)
         self.data_FiQuS.magnet.solve.pro_template = self.model_data.Options_FiQuS.multipole.solve.pro_template
+        self.data_FiQuS.magnet.solve.getdp_exe_path = self.model_data.Options_FiQuS.multipole.solve.getdp_exe_path
+        self.data_FiQuS.magnet.solve.BH_curves_path = self.model_data.Options_FiQuS.multipole.solve.BH_curves_path
 
         self.data_FiQuS.magnet.post_proc = self.model_data.Options_FiQuS.multipole.post_proc
