@@ -104,6 +104,15 @@ class AddAuxiliaryFile(BaseModel):
     new_file_name: str = None  # if empty, file is not renamed
 
 
+class CopyFile(BaseModel):
+    """
+        Level 2: Analysis step to copy one file from a location to another
+    """
+    type: Literal['CopyFile']
+    full_path_file_to_copy: str = None
+    full_path_file_target: str = None
+
+
 class RunSimulation(BaseModel):
     """
         Level 2: Analysis step to run a simulation file
@@ -148,5 +157,5 @@ class DataAnalysis(BaseModel):
     GeneralParameters: General = General()
     PermanentSettings: DataSettings = DataSettings()
     WorkingFolders: WorkingFolders = WorkingFolders()
-    AnalysisStepDefinition: Dict[str, Union[MakeModel, ModifyModel, ModifyModelMultipleVariables, SetUpFolder, AddAuxiliaryFile, RunSimulation, PostProcess]] = {}
+    AnalysisStepDefinition: Dict[str, Union[MakeModel, ModifyModel, ModifyModelMultipleVariables, SetUpFolder, AddAuxiliaryFile, CopyFile, RunSimulation, PostProcess]] = {}
     AnalysisStepSequence: List[str] = []  # Here the analysis steps are defined, in execution order. Names must be defined in AnalysisStepDefinition. Repetitions ARE allowed.
